@@ -1,27 +1,27 @@
-from typing import Dict
+from typing import Any, Dict, Type
 
-from pyonepassword.op_items.item_field_base import OPItemField
+from .item_field_base import OPItemField
 
 
 class OPItemFieldFactory:
-    _TYPE_REGISTRY = {}
+    _TYPE_REGISTRY: Dict[str, Type[OPItemField]] = {}
 
     @classmethod
     def register_op_field_type(cls, item_class):
         cls._TYPE_REGISTRY[item_class.FIELD_TYPE] = item_class
 
     @classmethod
-    def field_type_lookup(cls, field_dict):
+    def field_type_lookup(cls, field_dict: Dict[str, Any]):
         item_type = field_dict["type"]
-        field_class = None
+        field_class = OPItemField
         try:
             field_class = cls._TYPE_REGISTRY[item_type]
         except KeyError:
-            field_class = OPItemField
+            pass
         return field_class
 
     @classmethod
-    def item_field(cls, field_dict: Dict, *args):
+    def item_field(cls, field_dict: Dict[str, Any], *args):
         item_cls = cls.field_type_lookup(field_dict)
 
         obj = item_cls(field_dict)
